utils::globalVariables(c("CH", "Classification", "DB",
                         "Evaluation", "Metrics", "Sample",
                         "average_Silhouette", "k", "median_Silhouette", "maxk"))
